@@ -7,12 +7,10 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CRYPTOCONFIGMODULE_P_H
-#define CRYPTOCONFIGMODULE_P_H
-
-#include <QWidget>
+#pragma once
 
 #include <QList>
+#include <QWidget>
 
 class KLineEdit;
 class QSpinBox;
@@ -38,6 +36,7 @@ class CryptoConfigEntry;
 
 namespace Kleo
 {
+class CryptoConfigModule;
 class CryptoConfigComponentGUI;
 class CryptoConfigGroupGUI;
 class CryptoConfigEntryGUI;
@@ -50,8 +49,7 @@ class CryptoConfigComponentGUI : public QWidget
     Q_OBJECT
 
 public:
-    CryptoConfigComponentGUI(CryptoConfigModule *module, QGpgME::CryptoConfigComponent *component,
-                             QWidget *parent = nullptr);
+    CryptoConfigComponentGUI(CryptoConfigModule *module, QGpgME::CryptoConfigComponent *component, QWidget *parent = nullptr);
 
     bool save();
     void load();
@@ -70,15 +68,17 @@ class CryptoConfigGroupGUI : public QObject
     Q_OBJECT
 
 public:
-    CryptoConfigGroupGUI(CryptoConfigModule *module, QGpgME::CryptoConfigGroup *group,
-                         QGridLayout *layout, QWidget *parent = nullptr);
+    CryptoConfigGroupGUI(CryptoConfigModule *module,
+                         QGpgME::CryptoConfigGroup *group,
+                         const std::vector<QGpgME::CryptoConfigEntry *> &entries,
+                         QGridLayout *layout,
+                         QWidget *parent = nullptr);
 
     bool save();
     void load();
     void defaults();
 
 private:
-    QGpgME::CryptoConfigGroup *mGroup = nullptr;
     QList<CryptoConfigEntryGUI *> mEntryGUIs;
 };
 
@@ -89,10 +89,8 @@ private:
 class CryptoConfigEntryGUIFactory
 {
 public:
-    static CryptoConfigEntryGUI *createEntryGUI(
-        CryptoConfigModule *module,
-        QGpgME::CryptoConfigEntry *entry, const QString &entryName,
-        QGridLayout *layout, QWidget *widget);
+    static CryptoConfigEntryGUI *
+    createEntryGUI(CryptoConfigModule *module, QGpgME::CryptoConfigEntry *entry, const QString &entryName, QGridLayout *layout, QWidget *widget);
 };
 
 /**
@@ -102,9 +100,7 @@ class CryptoConfigEntryGUI : public QObject
 {
     Q_OBJECT
 public:
-    CryptoConfigEntryGUI(CryptoConfigModule *module,
-                         QGpgME::CryptoConfigEntry *entry,
-                         const QString &entryName);
+    CryptoConfigEntryGUI(CryptoConfigModule *module, QGpgME::CryptoConfigEntry *entry, const QString &entryName);
 
     void load()
     {
@@ -160,6 +156,7 @@ public:
 
     void doSave() override;
     void doLoad() override;
+
 private:
     KLineEdit *mLineEdit = nullptr;
 };
@@ -171,11 +168,15 @@ class CryptoConfigEntryDebugLevel : public CryptoConfigEntryGUI
 {
     Q_OBJECT
 public:
-    CryptoConfigEntryDebugLevel(CryptoConfigModule *module, QGpgME::CryptoConfigEntry *entry,
-                                const QString &entryName, QGridLayout *layout, QWidget *parent = nullptr);
+    CryptoConfigEntryDebugLevel(CryptoConfigModule *module,
+                                QGpgME::CryptoConfigEntry *entry,
+                                const QString &entryName,
+                                QGridLayout *layout,
+                                QWidget *parent = nullptr);
 
     void doSave() override;
     void doLoad() override;
+
 private:
     QComboBox *mComboBox = nullptr;
 };
@@ -196,6 +197,7 @@ public:
 
     void doSave() override;
     void doLoad() override;
+
 private:
     Kleo::FileNameRequester *mFileNameRequester = nullptr;
 };
@@ -216,6 +218,7 @@ public:
 
     void doSave() override;
     void doLoad() override;
+
 private:
     Kleo::FileNameRequester *mFileNameRequester = nullptr;
 };
@@ -235,6 +238,7 @@ public:
                              QWidget *parent = nullptr);
     void doSave() override;
     void doLoad() override;
+
 private:
     enum { Int, UInt, ListOfNone } mKind;
     QSpinBox *mNumInput = nullptr;
@@ -255,6 +259,7 @@ public:
                               QWidget *parent = nullptr);
     void doSave() override;
     void doLoad() override;
+
 private:
     QCheckBox *mCheckBox = nullptr;
 };
@@ -276,6 +281,7 @@ public:
     void doLoad() override;
 private Q_SLOTS:
     void slotOpenDialog();
+
 private:
     void setURLList(const QList<QUrl> &urlList);
     QLabel *mLabel = nullptr;
@@ -283,28 +289,4 @@ private:
     QList<QUrl> mURLList;
 };
 
-/**
- * A widget manager for a (OpenPGP) keyserver entry in the crypto config
- */
-class CryptoConfigEntryKeyserver : public CryptoConfigEntryGUI
-{
-    Q_OBJECT
-
-public:
-    CryptoConfigEntryKeyserver(CryptoConfigModule *module,
-                               QGpgME::CryptoConfigEntry *entry,
-                               const QString &entryName,
-                               QGridLayout *layout,
-                               QWidget *parent = nullptr);
-    void doSave() override;
-    void doLoad() override;
-private Q_SLOTS:
-    void slotOpenDialog();
-private:
-    QLabel *mLabel = nullptr;
-    QPushButton *mPushButton = nullptr;
-    ParsedKeyserver mParsedKeyserver;
-};
 }
-
-#endif // CRYPTOCONFIGMODULE_P_H
